class CRUDEmbed:
    def __init__(self, model, embed_name) -> None:
        self.model = model
        self.embed_name = embed_name
